@@ -6,7 +6,10 @@ from typing import Any
 from web.errors.app import InconsistencyError
 
 
-def string_from_db_date(db_date: datetime | Ddate | DTime | str | Any, iso_date_format=False) -> Any:
+def string_from_db_date(db_date: datetime | Ddate | DTime | str | Any, iso_date_format=False) -> str:
+    """
+    Convert a datetime object to a string
+    """
     v = db_date
     if isinstance(db_date, datetime):
         if iso_date_format:
@@ -24,6 +27,10 @@ def string_from_db_date(db_date: datetime | Ddate | DTime | str | Any, iso_date_
 
 
 def integrity_error_format(exception) -> InconsistencyError:
+    """
+    Formatting Tortoise exceptions.
+    :return  InconsistencyError
+    """
     str_exception = str(exception)
 
     if "table" in str_exception:  # tortoise.exceptions.IntegrityError: insert or update on table "issue" violates foreign key constraint "issue_service_id_fkey"
