@@ -59,6 +59,9 @@ TaskCompleteCallback = Callable[[JobExecutionEvent, Task], Coroutine[Any, Any, N
 
 
 class BackGroundIsolate(Isolate):
+    """
+    Isolate for run scheduler in separate process
+    """
     def __init__(self, name: str, *args, coro_stop_condition: str = asyncio.FIRST_EXCEPTION, **kwargs):
         super().__init__(name, *args, coro_stop_condition=coro_stop_condition, **kwargs)
 
@@ -80,7 +83,8 @@ class Scheduler(IScheduler, EnvAble):
     manager: ProcManager | None
     dispatcher: IDispatcher | None
 
-    def __init__(self, scheduler: BaseScheduler = None):
+    def __init__(self, scheduler: BaseScheduler = None, active_tasks_limit: int = 40):
+        self.active_tasks_limit = active_tasks_limit
         self.manager = None
         self.dispatcher = None
         self._tasks_info = {}
@@ -106,6 +110,9 @@ class Scheduler(IScheduler, EnvAble):
 
         def _on_job_exec(event: JobExecutionEvent):  # todo remove done jobs? YAROHA: NO, NEED TO STATISTICS
             task = self._tasks_info.get(event.job_id)
+            if not task:
+                loguru.logger.error(f"[Scheduler::Task::{task.id}] Job not found")
+                return
             task.done_time = datetime.datetime.now().astimezone()
             task.execution_time = task.done_time - task.call_time
             task.status = "done"
@@ -125,6 +132,8 @@ class Scheduler(IScheduler, EnvAble):
                     asyncio.create_task(task.on_complete_callback(event, task))
             asyncio.create_task(
                 self.env.channel.produce(task.trigger_event.reply(event.retval, event.exception)))
+            if not isinstance(task.trigger_event.trigger, IntervalTrigger):
+                self._tasks_info.pop(event.job_id, None)
 
         scheduler.add_listener(_on_job_submitted, EVENT_JOB_SUBMITTED)
         scheduler.add_listener(_on_job_exec, EVENT_JOB_EXECUTED | EVENT_JOB_ERROR)
@@ -169,6 +178,8 @@ class Scheduler(IScheduler, EnvAble):
                     job.kwargs = message.kwargs
                     return
 
+        while len(self._tasks_info) > self.active_tasks_limit:
+            await asyncio.sleep(0.001)
         job = self._scheduler.add_job(message.target,
                                       id=arc_task.id,
                                       name=arc_task.id,
