@@ -37,6 +37,10 @@ DtoType: TypeAlias = TypeVar("DtoType", bound=BaseModel)
 
 
 class IMessage:
+    """
+    Base  class for all messages to send via IChannels.
+    if exec_inner is set to True, the message will be executed in the context of the current process.
+    """
     message_type: str = "__all__"
     index: int
     inner_index: int
@@ -58,6 +62,10 @@ class IMessage:
 
 
 class IMessageReturn(IMessage):
+    """
+    Reply message.
+    """
+
     def __init__(self, response_to: IMessage, *args, **kwargs):
         super().__init__()
         self.inner_index = response_to.inner_index
@@ -74,8 +82,11 @@ class IMessageWaiter:
     _timeout: float
 
     def __init__(self, waiter: IChannel, question: IMessage, timeout: float = 0):
+        if not question.return_event_type:
+            raise AttributeError("Can't create IMessageWaiter without return_event_type")
         self.result = None
         self.waiter = waiter
+        self.wait_for_type = question.return_event_type.message_type
         self.wait_for_index = question.inner_index
         self._timeout = timeout
 
@@ -108,12 +119,15 @@ EventListener = Callable[[GenIMessage], Coroutine[Any, Any, Any]]
 
 
 class IChannel:
+    """
+    Channel for communicating workers
+    """
     read_timeout = 0.01
     name: str
     consume_pipe: Queue
     produce_pipe: Queue
     _listeners: Dict[str, List[EventListener]]
-    _response_waiters: Dict[int, IMessageWaiter]
+    _response_waiters: Dict[str, dict[int, IMessageWaiter]]
     _inner_index: int
 
     def __init__(self, idx: int, isolate_name: str):
@@ -129,6 +143,12 @@ class IChannel:
         return f"IChannel({self.name})"
 
     async def produce(self, msg: IMessage, need_answer: bool = False, answer_timeout: float = 0) -> IMessage | None:
+        """
+        Send message to all another processes channels.
+        :param need_answer:   if True, the message will be sent and will wait for an answer.
+        :param answer_timeout:
+        :return:
+        """
         raise NotImplementedError
 
     async def sent_to_consume(self, msg: IMessage):
@@ -144,17 +164,27 @@ class IChannel:
                            callback: EventListener, use_nested_classes: bool = False):
         raise NotImplementedError
 
+    def remove_event_listener(self, event_type: GenEventsType,
+                              callback: EventListener, use_nested_classes: bool = False):
+        raise NotImplementedError
+
     def set_waiter(self, waiter: IMessageWaiter):
-        self._response_waiters[waiter.wait_for_index] = waiter
+        if not self._response_waiters.get(waiter.wait_for_type):
+            self._response_waiters[waiter.wait_for_type] = {}
+        self._response_waiters[waiter.wait_for_type][waiter.wait_for_index] = waiter
 
     def answer_to_waiters(self, answer: IMessage):
-        waiter = self._response_waiters.get(answer.inner_index)
-        if waiter:
-            waiter.answer(message=answer)
-            self._response_waiters.pop(answer.inner_index)
+        if waiters := self._response_waiters.get(answer.message_type):
+            if waiter := waiters.pop(answer.inner_index, None):
+                waiter.answer(message=answer)
+                if not waiters:
+                    self._response_waiters.pop(answer.message_type)
 
 
 class SettingsChangeEvent(IMessage):
+    """
+    Settings change event must be produces if some setting in settings module is changed.
+    """
     message_type = "__change_settings_event__"
     name: str
     value: bool
@@ -178,6 +208,9 @@ GenAble = TypeVar("GenAble", bound=Able)
 
 
 class AppNameAble(Able):
+    """
+    Mixin for setting app name in class on start time
+    """
     __app_name: str
 
     @property
@@ -193,6 +226,9 @@ class AppNameAble(Able):
 
 
 class SharedStateAble(Able):
+    """
+    Mixin for setting shared state in class on start time.
+    """
     __shared_state: SharedState | None = None
 
     @property
@@ -208,6 +244,9 @@ class SharedStateAble(Able):
 
 
 class ChanAble(Able):
+    """
+    Mixin for setting process channel in class on start time.
+    """
     name: str
     __chan: IChannel | None = None
 
@@ -224,6 +263,9 @@ class ChanAble(Able):
 
 
 class ConfAble(Generic[GenConfig], Able):
+    """
+    Mixin for setting specific config from the config file at start time.
+    """
     __conf: GenConfig | None = None
 
     @property
@@ -239,6 +281,9 @@ class ConfAble(Generic[GenConfig], Able):
 
 
 class EnvAble(Able):
+    """
+    Mixin for setting Environment in class at start time.
+    """
     __env: Environment | None
 
     @property
@@ -253,22 +298,42 @@ class EnvAble(Able):
         self.__env = e
 
 
-def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool = True, nested_count: int = 1):
+def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool = True, nested_count: int = 1,
+          done_objects: list = None):
+    """
+    Set any Able subclass to any object recursively.
+    :param set_to: object to set
+    :param typed: Able subclass to set
+    :param value: Able subclass object to set
+    :param nested: set True if you need recursion
+    :param self: set True if you also need to set in first object
+    :param nested_count: recursion depth
+    :param done_objects: object that will be skipped
+    """
+    if done_objects is None:
+        done_objects = []
+
     def _set_conf_able(obj, conf) -> bool:
         for base in obj.__orig_bases__:
             if "ConfAble" in base.__name__:
                 conf_class = get_args(base)[0]
                 for attr in vars(conf).values():
                     if isinstance(attr, conf_class):
-                        obj.conf = attr
-                        loguru.logger.success(
-                            f"[CONF_ABLE::{obj.__class__.__name__}] Set {attr.__class__.__name__}")
+                        try:
+                            getattr(obj, "conf")
+                        except:
+                            obj.conf = attr
+                            loguru.logger.debug(
+                                f"[CONF_ABLE::{obj.__class__.__name__}] Set {attr.__class__.__name__}")
                         return True
                     elif issubclass(attr.__class__, BaseModel):
                         if _set_conf_able(obj, attr):
                             return True
             if base == Generic[GenConfig]:
-                obj.conf = value
+                try:
+                    getattr(obj, "conf")
+                except:
+                    obj.conf = value
                 return True
         return False
 
@@ -304,8 +369,11 @@ def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool
                     loguru.logger.error(
                         f"[CYCLE::{nested_count}][OBJECT::{_item.__class__.__name__}] NOT SET {typed.__name__}")
             if nested:
+                if _item in done_objects:
+                    return
+                done_objects.append(_item)
                 cheat(_item, typed, value,
-                      nested_count=nested_count + 1)
+                      nested_count=nested_count + 1, done_objects=done_objects)
 
     if self and typed in set_to.__class__.__mro__:
         set_up(set_to)
@@ -472,6 +540,9 @@ class SharedState(ChanAble):
 
 
 class Plugin(AppNameAble, EnvAble, SigAble, SharedStateAble, metaclass=ABCMeta):
+    """
+    Base class for all plugins
+    """
     name: str
     enabled: bool
     required_attrs: List[str] = []
@@ -484,6 +555,10 @@ class Plugin(AppNameAble, EnvAble, SigAble, SharedStateAble, metaclass=ABCMeta):
 
 
 class PluginContainer:
+    """
+    Container for plugin instances.
+    Load and init plugin on startup.
+    """
     _REGEX = re.compile(r"PLUGIN_NAME\s?=\s?[\"|'](.*)[\"|']")
     file_path: Path
     code: str
@@ -535,6 +610,9 @@ class PluginContainer:
 
 
 class SetPluginEvent(SetStateEvent):
+    """
+    Event for triggering plugin update on all workers
+    """
     message_type = "__set_plugin_state__"
     key: str
     destination: str = "__all__"
@@ -546,12 +624,18 @@ class SetPluginEvent(SetStateEvent):
 
 
 class RemovePluginEvent(RemoveStateEvent):
+    """
+    Event for triggering plugin removal on all workers
+    """
     message_type = "__remove_plugin_state__"
     destination: str = "__all__"
     exec_inner = True
 
 
 class PluginsStore(SharedState, EnvAble):
+    """
+    Store plugins in every worker
+    """
     _state: Dict[str, PluginContainer]
     dir_path: Path
     set_event_type: Type[IMessage] = SetPluginEvent
@@ -566,6 +650,8 @@ class PluginsStore(SharedState, EnvAble):
     def import_plugins(self):
         for filename in os.listdir(self.dir_path):
             plugin_path = self.dir_path.joinpath(str(filename))
+            if plugin_path.is_dir():
+                continue
             container = PluginContainer(plugin_path)
             msg_type, message = container.import_plugin()
             if settings.DEBUG:
@@ -593,6 +679,9 @@ class PluginsStore(SharedState, EnvAble):
         return super().local_store
 
 
+GenPluginFindFilter: TypeAlias = Callable[[..., any], bool]
+
+
 # --------------------------------------------------SPECIAL TYPES------------------------------------------------------
 
 class SocketConf(BaseModel):
@@ -601,6 +690,9 @@ class SocketConf(BaseModel):
 
 
 class ISocket(socket.socket):
+    """
+    Socket interface workers serving
+    """
     host: int
     port: int
     backlog: int
@@ -636,12 +728,29 @@ class TransportConf(BaseModel):
 
 
 class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, SigAble, metaclass=ABCMeta):
+    """
+    Base class for all transports
+    """
     services: List[GenService]
+    priority: int
+    workers: int
+    ignore_balance: bool
     rt_writers: Dict[Type[RtWriter], List[RtWriter]]
     plugins_dir: Path | None
+    plugins_filter: GenPluginFindFilter | None
     _plugins_store: PluginsStore | None
 
-    def __init__(self, services: List[GenService]):
+    def __init__(self, services: List[GenService],
+                 priority: int = 0, workers: int = 0, ignore_balance: bool = False):
+        """
+
+        :param services: list of services
+        :param priority: priority in CPU allocation. Any number
+        :param workers: direct number of workers.
+                Be careful, if workers > CPU count, will be raised exception
+        :param ignore_balance: if True - Transport  will not be taken into account in the count of CPU
+                    if True and num of workers not set, workers count will be equal to CPU count.
+        """
         EnvAble.__init__(self)
         self.services = services
         for service in self.services:
@@ -649,19 +758,29 @@ class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, Si
         self.rt_writers = {}
         self._plugins_store = None
         self.plugins_dir = None
+        self.plugins_filter = None
+        self.priority = priority
+        self.workers = workers
+        self.ignore_balance = ignore_balance
 
     def get_service(self, typed: Type[GenService]) -> GenService | None:
         for service in self.services:
             if isinstance(service, typed):
                 return service
 
-    def with_plugins(self, plugins_dir: Path):
+    def with_plugins(self, plugins_dir: Path,
+                     plugin_filter: GenPluginFindFilter = lambda *args, **kwargs: True) -> ITransport:
+        """
+        enable plugins in the transport
+        """
         if not plugins_dir.exists():
             raise FileNotFoundError(f"{plugins_dir} does not exist")
         self.plugins_dir = plugins_dir
+        self.plugins_filter = plugin_filter
         return self
 
     async def set_settings(self, name: str, value: Any):
+        setattr(settings, name, value)
         await self.channel.produce(SettingsChangeEvent(name, value))
 
     def init_plugins(self):
@@ -706,6 +825,10 @@ class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, Si
 
 
 class Resource(AppNameAble, ConfAble, ChanAble, metaclass=ABCMeta):
+    """
+    Base class for all resources.
+    Resource is some interface of object with active connection per worker (e.g. database, file system, etc.).
+    """
     __communicator: GenCommunicator | None
 
     def __init__(self, communicator: GenCommunicator | None = None):
@@ -729,6 +852,9 @@ class Resource(AppNameAble, ConfAble, ChanAble, metaclass=ABCMeta):
 
 
 class Environment(ConfAble, AppNameAble, ChanAble, SharedStateAble):
+    """
+    Environment is  a container for all resources, channels, config of worker.
+    """
     _resources: List[Resource]
 
     def __init__(self):
@@ -750,6 +876,10 @@ class Environment(ConfAble, AppNameAble, ChanAble, SharedStateAble):
 
 
 class IService:
+    """
+    Base class for all services.
+    will have channel and transport after start of worker.
+    """
     transport: ITransport
 
 
@@ -761,6 +891,10 @@ GenService = TypeVar("GenService", bound=IService)
 
 @dataclass
 class RtMessage:
+    """
+    Base class for all RT messages (like SSE, WS).
+    """
+
     def prepare(self, idx: int = 0, *args, **kwargs) -> str | bytes:
         raise NotImplementedError
 
@@ -773,6 +907,9 @@ GenRtMessage = TypeVar("GenRtMessage", bound=RtMessage)
 
 
 class RtWriter(Generic[GenRtMessage]):
+    """
+    Resolve RT connection.
+    """
     message_class: GenRtMessage
     last_index: int = 0
     obj: Any
@@ -828,6 +965,9 @@ class TaskReturnEvent(IMessageReturn):
 
 
 class TaskEvent(IMessage):
+    """
+    Event for start task in Scheduler.
+    """
     message_type = "__task__"
     destination = "__master__"
     target: BackTaskTarget
@@ -847,6 +987,11 @@ class TaskEvent(IMessage):
                  on_error: BackTaskCallback = None,
                  on_complete: BackTaskCallback = None):
         super().__init__()
+        if kwargs is None:
+            kwargs = {}
+        if args is None:
+            args = []
+
         self.target = target
         self.args = args
         self.kwargs = kwargs
@@ -857,6 +1002,9 @@ class TaskEvent(IMessage):
 
 
 class IScheduler:
+    """
+    Scheduler interface.
+    """
     _tasks_info: Dict[str, BackTaskTarget]
     state: Dict[str, Any]
 
