@@ -105,7 +105,7 @@ ProtectIdentityType = TypeVar("ProtectIdentityType", bound=ProtectIdentity)
 class InputContext(Generic[DtoType, ProtectIdentityType]):
     request: Request
     dto: DtoType | None
-    identity: ProtectIdentity | None
+    identity: ProtectIdentityType | None
     r_kwargs: Dict
 
 
@@ -115,6 +115,10 @@ HandlerType = Callable[[InputContext, Transport], Coroutine[Any, Any, HTTPRespon
 
 
 class CustomRequestHandler(ABC):
+    """
+    Default request handlers wrapper.
+    Validate dtos, run plugins, forming InputContext.
+    """
     protector: Protector | None
     in_struct: Type[PdModel] | None
     validation_fnc: DtoValidator | None
@@ -133,13 +137,14 @@ class CustomRequestHandler(ABC):
         self.validation_fnc = validation_fnc
         self.response_fabric = response_fabric
 
-    def __find_plugins(self, req) -> List[RestPlugin]:
+    def __find_plugins(self, ctx) -> List[RestPlugin]:
         find_plugins = []
+        plug_conf = PlugRouteConf(ctx.request.route.path, ctx.request.method)
         for plug in self.transport.plugins:
             if RestPlugin in plug.__class__.__mro__:
                 plug = cast(RestPlugin, plug)
                 for route_cfg in plug.routes_conf:
-                    if route_cfg == PlugRouteConf(req.route.path, req.method):
+                    if route_cfg == plug_conf and self.transport.plugins_filter(plug, ctx):
                         find_plugins.append(plug)
         return find_plugins
 
@@ -157,7 +162,7 @@ class CustomRequestHandler(ABC):
             incoming = InputContext(req, validated, prot_identity, kwargs)
             ret_val = None
             try:
-                plugins = self.__find_plugins(req)
+                plugins = self.__find_plugins(incoming)
                 if plugins:
                     if settings.DEBUG:
                         loguru.logger.debug(
@@ -189,6 +194,7 @@ class CustomRouter(Router, ConfAble[RouterConf]):
         super().__init__()
         self._router_conf = routes_config
         self.open_api = open_api
+        self.__setted = False
 
     @classmethod
     def set_serving_config(cls, sanic: Sanic, config):
@@ -213,13 +219,19 @@ class CustomRouter(Router, ConfAble[RouterConf]):
 
                             return static_route
 
-                        sanic.add_route(get_static_route(serv_path_target), serv_path.uri)
+                        static_func = get_static_route(serv_path_target)
+                        static_func.__name__ = "static_" + "_".join(serv_path_target.split('/'))
+                        sanic.add_route(static_func, serv_path.uri)
                 else:
                     if not os.path.exists(serv_path_target):
                         os.makedirs(serv_path_target, exist_ok=True)
-                    sanic.static(serv_path.uri, file_or_directory=serv_path_target)
+                    sanic.static(serv_path.uri, file_or_directory=serv_path_target,
+                                 name="static_" + "_".join(serv_path_target.split('/')))
 
     def set_routes(self, transport: Transport):
+        """
+        Parse routes from routes_dict and add them to sanic.
+        """
         version_prefix = self._router_conf.get("version_prefix")
         version_prefix = version_prefix if version_prefix else "/api/v"
         for endpoint, versions in self._router_conf.get("endpoints").items():
@@ -237,8 +249,6 @@ class CustomRouter(Router, ConfAble[RouterConf]):
                         continue
                     target_func = method_params.get('handler')
                     target_func = target_func if target_func else endpoint_handler
-                    # TODO: avoid deprecation in sanic
-                    target_func.__name__ = method_name + target_func.__name__
                     protector = method_params.get("protector")
                     protector = protector if protector else endpoint_protector
                     in_dto = method_params.get("in_dto")
@@ -267,14 +277,17 @@ class CustomRouter(Router, ConfAble[RouterConf]):
                         self.ctx.app.add_websocket_route(
                             handler=chain,
                             uri=endpoint,
+                            name=f"__{method_name}_{chain.__name__}",
                             version=version,
                             version_prefix=version_prefix
                         )
                     else:
+                        chain.__name__ = f"__{method_name}_{chain.__name__}"
                         self.ctx.app.add_route(
                             uri=endpoint,
                             methods={method_name.upper()},
                             handler=chain,
+                            name=f"__{method_name}_{chain.__name__}",
                             version=version,
                             version_prefix=version_prefix
                         )
@@ -292,6 +305,12 @@ class CustomRouter(Router, ConfAble[RouterConf]):
                     self.ctx.app.config.OAS = False
         except RuntimeError:
             pass
+        self.__setted = True
+
+    def extend_routes(self, new_routes: dict[str, dict[str, dict]]):
+        if self.__setted:
+            raise Exception("Routes are already setted")
+        self._router_conf['endpoints'].update(new_routes)
 
 
 class StatusCodes:
@@ -300,6 +319,10 @@ class StatusCodes:
 
 
 class CustomJSONRenderer(JSONRenderer):
+    """
+    Custom JSONRenderer for sanic.
+    Formatting error responses in json.
+    """
     def _generate_output(self, *, full):
         output = {
             "description": self.title,
