@@ -41,6 +41,9 @@ class SseRtMessage(RtMessage):
 
 
 class SseWriter(RtWriter):
+    """
+    Serve sse connection
+    """
     message_class = SseRtMessage
     obj: BaseHTTPResponse
     ping_enable: bool
