@@ -15,6 +15,16 @@ def set_access_endpoints(access_endpoints: dict, models,
                          db_model_responses: dict[Type[Model]], get_out_struct_func: Callable,
                          get_list_out_struct_func: Callable, drop_filter_fields: list[str],
                          scope: str = None):
+    """
+    Resolve access endpoint. Add .../<entity_id> routes, add out_dtos, set openapi params.
+    :param access_endpoints: dict of access endpoints
+    :param models: module with Tortoise models
+    :param db_model_responses: dict  of db model responses (Pydantic models)
+    :param get_out_struct_func:  function to get out struct from db model
+    :param get_list_out_struct_func:  function to get list out struct from db model
+    :param drop_filter_fields:  list of fields to drop from out_dtos
+    :param scope: scope name  (for example: "access")
+    """
     params_filters = {
         "not": Schema(description="not definition", type="string"),
 
@@ -87,6 +97,13 @@ def set_access_endpoints(access_endpoints: dict, models,
                     else:
                         out_struct = None
 
+                def new_wrap(func):  # wrapper to change handler signature (need for openapi)
+                    @wraps(func)
+                    def wr(*args, **kwargs):
+                        return func(*args, **kwargs)
+
+                    return wr
+
                 # add routes with <entity_id>
                 if method_name in ['patch', 'delete', 'get']:
                     if method_name != 'get':
@@ -103,6 +120,9 @@ def set_access_endpoints(access_endpoints: dict, models,
                             }
                         })
                     access_endpoints[f"{endpoint}/<entity_id:int>"][version].update({method_name: copy(param)})
+                    get_entity_access_func = new_wrap(target_func)
+                    get_entity_access_func.__name__ = f"{get_entity_access_func.__name__}__read_entity"
+                    access_endpoints[f"{endpoint}/<entity_id:int>"][version][method_name]['handler'] = get_entity_access_func
                     if scope:
                         access_endpoints[f"{endpoint}/<entity_id:int>"][version]['scope'] = scope
 
@@ -112,13 +132,6 @@ def set_access_endpoints(access_endpoints: dict, models,
                     if not access_endpoints[endpoint].get(version):
                         access_endpoints[endpoint].pop(version)
 
-                def new_wrap(func):  # wrapper to change handler signature (need for openapi)
-                    @wraps(func)
-                    def wr(*args, **kwargs):
-                        return func(*args, **kwargs)
-
-                    return wr
-
                 if method_name == 'get' and 'entity_id' not in endpoint and out_struct:
                     get_access_func = new_wrap(target_func)
                     get_access_func.__name__ = f"{get_access_func.__name__}__read"
