@@ -1,16 +1,15 @@
-import asyncio
 from dataclasses import dataclass, field
+from typing import Iterable
 
-import loguru
 from sanic.server.websockets.impl import WebsocketImplProtocol
-from websockets.connection import OPEN
+from websockets.typing import Data
 
 from web.kernel.types import RtMessage, RtWriter, RtReadCallback
 
 
 @dataclass
 class WsRtMessage(RtMessage):
-    msg: str = field(default="")
+    msg: Data | Iterable[Data] = field(default="")
 
     def prepare(self, *args, **kwargs) -> str | bytes:
         return self.msg
@@ -21,6 +20,9 @@ class WsRtMessage(RtMessage):
 
 
 class WsWriter(RtWriter[WsRtMessage]):
+    """
+    Resolve WebSocket communication
+    """
     read_callback: RtReadCallback
     obj: WebsocketImplProtocol
 
@@ -29,7 +31,7 @@ class WsWriter(RtWriter[WsRtMessage]):
         super().__init__(obj)
         self.read_callback = read_callback
 
-    async def write(self, message: str) -> None:
+    async def write(self, message: Data | Iterable[Data]) -> None:
         await self.obj.send(message)
 
     async def freeze(self, ping_enable: bool = False, ping_timeout: int = 5):
